@@ -43,7 +43,10 @@ heredoc <- function(text, leave = 0) {
   # compute common indent
   indent <- regexpr("[^[:space:]]", lines)
   common <- min(setdiff(indent, -1L)) - leave
-  paste(substring(lines, common), collapse = "\n")
+  text <- paste(substring(lines, common), collapse = "\n")
+
+  # substitute in ANSI links for executable renv code
+  ansify(text)
 
 }
 
@@ -207,7 +210,11 @@ renv_bootstrap_download_impl <- function(url, destfile) {
   )
 
   if ("headers" %in% names(formals(utils::download.file)))
-    args$headers <- renv_bootstrap_download_custom_headers(url)
+  {
+    headers <- renv_bootstrap_download_custom_headers(url)
+    if (length(headers) && is.character(headers))
+      args$headers <- headers
+  }
 
   do.call(utils::download.file, args)
 
@@ -286,10 +293,22 @@ renv_bootstrap_download_cran_latest_find <- function(version) {
   for (type in types) {
     for (repos in renv_bootstrap_repos()) {
 
+      # build arguments for utils::available.packages() call
+      args <- list(type = type, repos = repos)
+
+      # add custom headers if available -- note that
+      # utils::available.packages() will pass this to download.file()
+      if ("headers" %in% names(formals(utils::download.file)))
+      {
+        headers <- renv_bootstrap_download_custom_headers(url)
+        if (length(headers) && is.character(headers))
+          args$headers <- headers
+      }
+
       # retrieve package database
       db <- tryCatch(
         as.data.frame(
-          utils::available.packages(type = type, repos = repos),
+          do.call(utils::available.packages, args),
           stringsAsFactors = FALSE
         ),
         error = identity
@@ -371,6 +390,14 @@ renv_bootstrap_download_tarball <- function(version) {
 
 }
 
+renv_bootstrap_github_token <- function() {
+  for (envvar in c("GITHUB_TOKEN", "GITHUB_PAT", "GH_TOKEN")) {
+    envval <- Sys.getenv(envvar, unset = NA)
+    if (!is.na(envval))
+      return(envval)
+  }
+}
+
 renv_bootstrap_download_github <- function(version) {
 
   enabled <- Sys.getenv("RENV_BOOTSTRAP_FROM_GITHUB", unset = "TRUE")
@@ -378,16 +405,16 @@ renv_bootstrap_download_github <- function(version) {
     return(FALSE)
 
   # prepare download options
-  pat <- Sys.getenv("GITHUB_PAT")
-  if (nzchar(Sys.which("curl")) && nzchar(pat)) {
+  token <- renv_bootstrap_github_token()
+  if (nzchar(Sys.which("curl")) && nzchar(token)) {
     fmt <- "--location --fail --header \"Authorization: token %s\""
-    extra <- sprintf(fmt, pat)
+    extra <- sprintf(fmt, token)
     saved <- options("download.file.method", "download.file.extra")
     options(download.file.method = "curl", download.file.extra = extra)
     on.exit(do.call(base::options, saved), add = TRUE)
-  } else if (nzchar(Sys.which("wget")) && nzchar(pat)) {
+  } else if (nzchar(Sys.which("wget")) && nzchar(token)) {
     fmt <- "--header=\"Authorization: token %s\""
-    extra <- sprintf(fmt, pat)
+    extra <- sprintf(fmt, token)
     saved <- options("download.file.method", "download.file.extra")
     options(download.file.method = "wget", download.file.extra = extra)
     on.exit(do.call(base::options, saved), add = TRUE)
