@@ -1,20 +1,4 @@
 
-renv_repos_encode <- function(x) {
-  if (length(x) == 1)
-    paste(names(x), as.character(x), sep = "=")
-  else
-    paste(sprintf("\n\t%s=%s", names(x), as.character(x)), collapse = "")
-}
-
-renv_repos_decode <- function(x) {
-  parts <- strsplit(trimws(x), "(?:,|\\s)+")[[1]]
-  idx <- regexpr("=", parts, fixed = TRUE)
-  keys <- substring(parts, 1, idx - 1)
-  vals <- substring(parts, idx + 1)
-  as.list(named(trimws(vals), trimws(keys)))
-}
-
-
 renv_repos_normalize <- function(repos = getOption("repos")) {
 
   # ensure repos are a character vector
@@ -24,23 +8,29 @@ renv_repos_normalize <- function(repos = getOption("repos")) {
   cran <- getOption("renv.repos.cran", "https://cloud.r-project.org")
   repos[repos == "@CRAN@"] <- cran
 
-  # if repos is length 1 but has no names, then assume it's CRAN
-  nms <- names(repos) %||% rep.int("", length(repos))
-  if (identical(nms, ""))
-    nms <- names(repos) <- "CRAN"
-
   # ensure all values are named
-  unnamed <- !nzchar(nms)
-  if (any(unnamed)) {
-    nms[unnamed] <- paste0("V", seq_len(sum(unnamed)))
-    names(repos) <- nms
-  }
+  names(repos) <- renv_repos_names(repos)
 
   # return normalized repository
   repos
 
 }
 
+renv_repos_names <- function(repos) {
+
+  # if repos is length 1 but has no names, then assume it's CRAN
+  nms <- names(repos) %||% rep.int("", length(repos))
+  if (identical(nms, ""))
+    return("CRAN")
+
+  # otherwise, just use the repository URLs as placeholder names
+  nms <- names(repos)
+  unnamed <- !nzchar(nms)
+  nms[unnamed] <- repos[unnamed]
+  nms
+
+}
+
 renv_repos_validate <- function(repos = getOption("repos")) {
 
   # allow empty repository explicitly
